Module: Ompload

Defined in:
lib/ompload.rb

Defined Under Namespace

Modules: CLI, Message, UploadsHandler Classes: ThrottledError

Constant Summary collapse

VERSION =
'1.0.2'
MAX_FILE_SIZE =
2**20
USAGE =
"  Usage: ompload [-h|--help] [options] [file(s)]\n    -q, --quiet     Only output errors and warnings\n    -u, --url       Only output URLs\n    -f, --filename  File name on omploader for when piping data via stdin\n    -n, --no-clip   Disable copying of the URL to the clipboard\n    -v, --version   Show version\n\n    You can supply a list of files or data via stdin (or both)\n".gsub(/^    /, '')